
/*
 projekt:	gme
 abschnitt:	verwaltung von standardschreiben
 history: 
	2014-11-20	klopfer: erstellt
	2015-01-09	klopfer: liefert ggf. das Datum des Schreibens und den Ortsteil
	2015-02-04	klopfer: mit bAntragsrueckgabe
	2015-11-10	klopfer: EmpfaengerlisteMuster42 hinzu; nicht bentigte Docs raus
	2016-09-18	klopfer: Firmenprofil hinzu
	2016-10-25	klopfer: ersetzt Platzhalter fr weiche Umbrche
	2016-11-13	klopfer: ordnet nun Bescheinigungen (Skript wird auch fr Erstattungen verwendet und nur dort werden mehrere Flle zugleich abgefragt)
	2020-11-20	klopfer: Rcknahme hinzu
	2020-12-06	klopfer: aArt und fName2 hinzu
	2021-03-18	klopfer: Korrektur: f_fNameX statt fNameX
	
 ::dv_vorlage und dv_gruppe haben identity-felder; vor dem eintrag eines datensatzes per script identity_insert auf on; alle ID-werte kleiner 0
 ::loescht temporaer alle standardschreiben und erzeugt sie neu

	******************************************************/

set nocount on
set QUOTED_IDENTIFIER OFF -- dadurch knnen " zur Begrenzung der SQL und innerhalb der SQL ' verwendet werden

declare @mdID int, @awID int, @dvgID int
select @mdID = 1 -- pseudo, nicht mandanten-abhngig
select @awID = 1 -- dgl.

alter table dv_vorlage disable trigger all
-- Vorlagen lschen:
delete from dv_vorlage where dvvID < 0

set identity_insert dv_vorlage on


insert into dv_vorlage (dvvGruppe, dvvID, dvvBezeichnung, dvvDateiname, dvvDateiname2, dvvGueltig, dvvMandant, dvvAnwendung, dvvSchuetzen, dvvVersteckt, dvvAuchOhneDatenabfrage, UPD_TIME, UPD_USER)
values (@dvgID, -100, 'Mitteilung und Erklrung', 'MitteilungUndErklrung.docx', '', 'T', @mdID, @awID, 'F', 'F', 'F', GETDATE(), SUSER_SNAME())

update dv_vorlage set dvvDatenabfrage = '
/*
 Datenabfrage fr Serienbriefe; wird auch von anderen Serienbriefen genutzt
 2014-11-20 klopfer: erstellt
 2014-11-29	klopfer: Rechtsgrundlage1/2 hinzu
 2015-01-11	klopfer: fOrtsteil hinzu
 2020-12-06	klopfer: aArt hinzu, fName2 zu fName hinzu
 2022-07-11	klopfer: Ortsteil vor der Strae; bSektor statt fSektor
*/

declare @st datetime
declare @ls varchar(4000)
declare @nurZertifizierte char(1)
declare @von datetime, @bis datetime, @heute datetime, @minDate datetime
select @minDate = convert(datetime, "01.01.1900", 104)
select @heute = getDate()

/* temporaere tabelle erzeugen:*/
create table #t (
  fName nvarchar(255) null
  , fNameX nvarchar(520) null
  , fStrasseX nvarchar(102) null
  , fStrasse nvarchar(50) null
  , fPLZ_Ort nvarchar(60) null
  , fIBAN varchar(50) null
  , fBIC varchar(20) null
  , fBankname nvarchar(80) null
  , fFax varchar(35) null
  , fSektor int null
  , aBezeichnung nvarchar(255) null
  , aArt char(1) null
  , aVon varchar(10) null
  , aBis varchar(10) null
  , bMitteilungVom varchar(10) null
  , bBeihilfeVorauss money null
  , bErstattung money null
  , bAntragsrueckgabe varchar(10) null
  , bAntragsrueckgabe2 varchar(10) null
  , aTermin varchar(10) null
  , aAktenzeichen varchar(30) null
  , bNameX varchar(255) null
  , zvbTelefon varchar(35) null
  , zvbTelefax varchar(35) null
  , zvbEMail varchar(35) null
  , DokDatum varchar(10) null
)

/* grunddaten laden */
insert into #t (
	fName
	, fNameX
	, fStrasseX
	, fStrasse
	, fPLZ_Ort
	, fIBAN
	, fBIC
	, fBankname
	, fFax
	, fSektor
	, aBezeichnung
	, aArt
	, aVon
	, aBis
	, bMitteilungVom
	, bBeihilfeVorauss
	, bErstattung
	, bAntragsrueckgabe
	, bAntragsrueckgabe2
	, aTermin
	, aAktenzeichen
	, bNameX
	, zvbTelefon
	, zvbTelefax
	, zvbEMail
	, DokDatum
)
select
	fName + case when isnull(fName2, "") = "" then "" else char(10) + fName2 end
	, dbo.f_fNameX(fID)
	, case when isnull(fOrtsteil, "") = "" then "" else fOrtsteil + char(10) end + fStrasse
	, fStrasse
	, isnull(fPLZ, "") + " " + isnull(fOrt, "")
	, fIBAN
	, fBIC
	, fBankname
	, fFax
	, bSektor
	, aBezeichnung
	, isnull(aArt, "w") 
	, convert(varchar(10), aVon, 104)
	, convert(varchar(10), aBis, 104)
	, convert(varchar(10), bMitteilungVom, 104)
	, bBeihilfeVorauss
	, bErstattung
	, convert(varchar(10), bAntragsrueckgabe, 104)
	, convert(varchar(10), bAntragsrueckgabe2, 104)
	, convert(varchar(10), aTermin, 104)
	, aAktenzeichen
	, dbo.f_zvbName(zvbID)
	, zvbTelefon
	, zvbTelefax
	, zvbEMail
	, convert(varchar(10), isnull(case @dvvID when -100 then bMitteilungVom when -300 then bErstattungVom else null end, getDate()), 104)
from beteiligung 
		join firma on bFirma = fID
		join aktion on bAktion = aID
		left outer join zv_benutzer on aBearbeiter = zvbID
where @kontext
order by fName
'
where dvvID = -100

insert into dv_vorlage (dvvGruppe, dvvID, dvvBezeichnung, dvvDateiname, dvvDateiname2, dvvGueltig, dvvMandant, dvvAnwendung, dvvSchuetzen, dvvVersteckt, dvvAuchOhneDatenabfrage, UPD_TIME, UPD_USER, dvvDatenabfrageAus)
values (@dvgID, -300, 'Erstattung', 'Erstattung.docx', '', 'T', @mdID, @awID, 'F', 'F', 'F', GETDATE(), SUSER_SNAME(), -100)

insert into dv_vorlage (dvvGruppe, dvvID, dvvBezeichnung, dvvDateiname, dvvDateiname2, dvvGueltig, dvvMandant, dvvAnwendung, dvvSchuetzen, dvvVersteckt, dvvAuchOhneDatenabfrage, UPD_TIME, UPD_USER, dvvDatenabfrageAus)
values (@dvgID, -305, 'Rcknahme', 'Rcknahme.docx', '', 'T', @mdID, @awID, 'F', 'F', 'F', GETDATE(), SUSER_SNAME(), -100)

insert into dv_vorlage (dvvGruppe, dvvID, dvvBezeichnung, dvvDateiname, dvvDateiname2, dvvGueltig, dvvMandant, dvvAnwendung, dvvSchuetzen, dvvVersteckt, dvvAuchOhneDatenabfrage, dvvDatenzeilenProSeite, UPD_TIME, UPD_USER)
values (@dvgID, -310, 'Empfngerliste', 'EmpfngerlisteMuster42.docx', '', 'T', @mdID, @awID, 'F', 'F', 'F', 5, GETDATE(), SUSER_SNAME())

update dv_vorlage set dvvDatenabfrage = '
/*
 Datenabfrage fr die Empfngerliste fr Erstattungen
 2015-11-10 klopfer: erstellt
 2020-12-06	klopfer: fName2
*/

declare @st datetime
declare @ls varchar(4000)
declare @nurZertifizierte char(1)
declare @von datetime, @bis datetime, @heute datetime, @minDate datetime
declare @ZEILENPROSEITE int

select @minDate = convert(datetime, "01.01.1900", 104)
select @heute = getDate()
select @ZEILENPROSEITE = 5

/* temporaere tabelle erzeugen:*/
create table #t (
  Buchungsstelle nvarchar(50) null
  , Anordnungsstelle nvarchar(50) null
  , fName nvarchar(520) null
  , fStrasse nvarchar(102) null
  , fPLZ_Ort nvarchar(60) null
  , fIBAN varchar(50) null
  , fBIC varchar(20) null
  , Aktion nvarchar(255) null
  , Zeitraum nvarchar(255) null
  , bErstattung money null
  , BlNr int null
  , BlSum money null
  , Ident int identity not null
  , Ordnung int null
  , Next int null
)

/* grunddaten laden */
insert into #t (
	Buchungsstelle
	, Anordnungsstelle
	, fName
	, fStrasse
	, fPLZ_Ort
	, fIBAN
	, fBIC
	, Aktion
	, Zeitraum
	, bErstattung
)
select
	dbo.f_zveTextWert("Empfngerliste", "Buchungsstelle")
	, dbo.f_zveTextWert("Empfngerliste", "Anordnungsstelle")
	, dbo.f_fNameX(fID)
	, fStrasse + case when isnull(fOrtsteil, "") = "" then "" else char(10) + fOrtsteil end
	, isnull(fPLZ, "") + " " + isnull(fOrt, "")
	, fIBAN
	, fBIC
	, aBezeichnung
	, case when aVon is null 
	  then cast(aJahr as varchar) 
	  else 
		case when aBis is null then "am " else "von " end 
		+ convert(varchar, aVon, 104) 
		+ case when aBis is null then "" else " bis " + convert(varchar, aBis, 104) end 
	  end
	, bErstattung
from beteiligung 
		join firma on bFirma = fID
		join aktion on bAktion = aID
where @kontext
order by fName

-- Berechnungen:
update #t set Ordnung = Ident - (select min(Ident) from #t) + 1
update #t set BlNr = (Ordnung - 1) / @ZEILENPROSEITE + 1
update #t set BlSum = (select sum(isnull(bErstattung, 0)) from #t ta where ta.BlNr = #t.BlNr) 
--
-- wenn die letzte Seite nicht vollstndig gefllt wird, einen leeren Datensatz mit der letzten Seitensumme anhngen, 
-- damit nicht alle verbleibenden Zeilen die Daten des letzten gltigen Datensatzes erhalten:
if (((select count(*) from #t) % @ZEILENPROSEITE) <> 0) insert into #t (BlSum) select BlSum from #t where Ident = (select max(Ident) from #t)
--
-- Info an Word, ob zu neuem Datensatz vorgerckt werden soll:
update #t set Next = case when Ident < (select max(Ident) from #t) then 1 else 0 end
'
where dvvID = -310



/*** Firmenprofil *****************************************************************************************************************/

insert into dv_vorlage (dvvGruppe, dvvID, dvvBezeichnung, dvvDateiname, dvvDateiname2, dvvGueltig, dvvMandant, dvvAnwendung, dvvSchuetzen, dvvVersteckt, dvvAuchOhneDatenabfrage, UPD_TIME, UPD_USER)
values (@dvgID, -320, 'Firmenprofil', 'Firmenprofil.docx', '', 'T', @mdID, @awID, 'F', 'F', 'F', GETDATE(), SUSER_SNAME())

update dv_vorlage set dvvDatenabfrage = '
/*
 Datenabfrage fr das Firmenprofil
 2016-09-18 klopfer: erstellt
 2020-12-06	klopfer: fName2
 2021-03-21	klopfer: fBranchen_R, fBereiche_R
*/

declare @st datetime
declare @ls varchar(4000)
declare @von datetime, @bis datetime, @heute datetime, @minDate datetime
declare @CRLF char(2)

select @CRLF = char(13) + char(10)
select @minDate = convert(datetime, "01.01.1900", 104)
select @heute = getDate()

/* temporaere tabelle erzeugen:*/
create table #t (
	fName nvarchar(520) null
	, Inhaber nvarchar(255) null
	, Anschrift nvarchar(255) null
	, Mutterfirma nvarchar(255) null
	, fTelefon varchar(255) null
	, fFax varchar(255) null
	, fEMail varchar(255) null
	, fHomepage varchar(50) null
	, fGruendungsjahr int null
	, fBeschaeftigte int null, fBeschaeftigteJahr varchar(10) null
	, fAzubi int null, fAzubiJahr varchar(10) null
	, fUmsatz money null, fUmsatzJahr varchar(10) null
	, Branche nvarchar(max) null
	, Bereich nvarchar(max) null
	, fProdukte nvarchar(255) null
	, fNeuheiten nvarchar(255) null
	, Bio varchar(10) null
	, Direktvermarkter varchar(10) null
	, fVertriebsweg nvarchar(255) null
	, fBesonderheiten nvarchar(255) null
	, fExport nvarchar(255) null
	, fBemerkung nvarchar(255) null
)

/* grunddaten laden */
insert into #t (
	fName
	, Inhaber
	, Anschrift
	, Mutterfirma
	, fTelefon
	, fFax
	, fEMail
	, fHomepage
	, fGruendungsjahr
	, fBeschaeftigte, fBeschaeftigteJahr
	, fAzubi, fAzubiJahr
	, fUmsatz, fUmsatzJahr
	, Branche
	, Bereich
	, fProdukte
	, fNeuheiten
	, Bio
	, Direktvermarkter
	, fVertriebsweg
	, fBesonderheiten
	, fExport
	, fBemerkung
)
select
	dbo.f_fNameX(fID) as fName
	, dbo.f_Inhaber(fID)
	, dbo.f_Anschrift(fID)
	, dbo.f_Mutterfirma(fID)
	, fTelefon
	, fFax
	, fEMail
	, fHomepage
	, fGruendungsjahr
	, fBeschaeftigte, case when isnull(fBeschaeftigteJahr, 0) = 0 then '''' else '' ('' + cast(fBeschaeftigteJahr as varchar) + '')'' end
	, fAzubi, case when isnull(fAzubiJahr, 0) = 0 then '''' else '' ('' + cast(fAzubiJahr as varchar) + '')'' end
	, fUmsatz, case when isnull(fUmsatzJahr, 0) = 0 then '''' else '' ('' + cast(fUmsatzJahr as varchar) + '')'' end
	, fBranchen_R
	, fBereiche_R
	, replace(fProdukte, @CRLF, ''@sb'')
	, replace(fNeuheiten, @CRLF, ''@sb'')
	, case when isnull(fBio, ''F'') = ''T'' then ''ja'' else ''nein'' end Bio
	, case when isnull(fDirektvermarkter, ''F'') = ''T'' then ''ja'' else ''nein'' end Direktvermarkter
	, replace(fVertriebsweg, @CRLF, ''@sb'')
	, replace(fBesonderheiten, @CRLF, ''@sb'')
	, replace(fExport, @CRLF, ''@sb'')
	, replace(fBemerkung, @CRLF, ''@sb'')
from firma
where @kontext

'
where dvvID = -320


set identity_insert dv_vorlage off
alter table dv_vorlage enable trigger all
	
set QUOTED_IDENTIFIER on
